/******************************************************************************
//                                                                           //
//  Project: Software Interface for DAFG-1 Devices                           //
//                                                                           //
//  CGC Instruments, (c) 2010, Version 1.00. All rights reserved.            //
//                                                                           //
//  Definition for COM-DAFG DLL Routines                                     //
//                                                                           //
******************************************************************************/

#ifndef __COM_DAFG_H__
#define __COM_DAFG_H__


#ifdef __cplusplus
extern "C" {
#endif


/*
	The communication channel must be opened before the first usage.

	If necessary, the channel may be closed and reopened again.
	The channel is closed automatically at the end of the program, the main program does not need to take care about it.

	The return values of the routines are the following defines COM_DAFG_ERR_XXX
		 0: routine finished without any error
		<0: errors COM_DAFG_ERR_XXX

	The last error code can be obtained by calling COM_DAFG_State.
	The routine COM_DAFG_ErrorMessage returns a pointer to a zero-terminated character string or NULL in case of a failure.

	If a communication error occurred, the error code can be red again by COM_DAFG_IO_State,
	The routine COM_DAFG_IO_ErrorMessage provides the corresponding error message.
*/

#define COM_DAFG_ERR_INI              -1 /* Error processing the COM.ini file */
#define COM_DAFG_ERR_OPEN             -2 /* Error opening the port */
#define COM_DAFG_ERR_CLOSE            -3 /* Error closing the port */
#define COM_DAFG_ERR_PURGE            -4 /* Error purging the port */
#define COM_DAFG_ERR_CONTROL          -5 /* Error setting the port control lines */
#define COM_DAFG_ERR_STATUS           -6 /* Error reading the port status lines */
#define COM_DAFG_ERR_COMMAND_SEND     -7 /* Error sending command */
#define COM_DAFG_ERR_DATA_SEND        -8 /* Error sending data */
#define COM_DAFG_ERR_TERM_SEND        -9 /* Error sending termination character */
#define COM_DAFG_ERR_COMMAND_RECEIVE -10 /* Error receiving command */
#define COM_DAFG_ERR_DATA_RECEIVE    -11 /* Error receiving data */
#define COM_DAFG_ERR_TERM_RECEIVE    -12 /* Error receiving termination character */
#define COM_DAFG_ERR_COMMAND_WRONG   -13 /* Wrong command received */
#define COM_DAFG_ERR_ARGUMENT_WRONG  -14 /* Wrong argument received */
#define COM_DAFG_ERR_ARGUMENT        -15 /* Wrong argument passed to the function */

#define COM_DAFG_ERR_NOT_CONNECTED -100 /* Device not connected */
#define COM_DAFG_ERR_NOT_READY     -101 /* Device not ready */
#define COM_DAFG_ERR_READY         -102 /* Device state could not be set to not ready */

/* Communication */
int FAR _export pascal COM_DAFG_Open();  /* Open the port  */
int FAR _export pascal COM_DAFG_Close(); /* Close the port */

int FAR _export pascal COM_DAFG_Purge();                     /* Clear data buffers for the port */
int FAR _export pascal COM_DAFG_Buffer_State (BOOL & empty); /* Return true if the input data buffer of the device is empty */
int FAR _export pascal COM_DAFG_Device_Purge (BOOL & empty); /* Clear output data buffer of the device, return value as COM_DAFG_Buffer_State */

/* Waveform management */
#define WAVEFORM_NAME_SIZE          24 /* Size of the waveform name */
#define WAVEFORM_NUMBER            100 /* Maximum waveform number */
#define MAX_WAVEFORM_SIZE      0x10000 /* Maximum total size of the waveform data */
#define MEM_ORIGIN_MULT              8 /* Multiplicator for calculating the waveform data origin */
#define MEM_WAVEFORM_SIZE      0x7F000 /* Memory space for the waveform data */
#define MAX_WAVEFORM_BLOCK_SIZE  0x100 /* Maximum size of the data block passed to the functions COM_DAFG_SetWaveformData/COM_DAFG_GetWaveformData */
#define WAVEFORM_DATA_ZERO      0x8000 /* Waveform data value corresponding to zero */
#define WAVEFORM_DATA_SCALE     0x7FFF /* Waveform data scale corresponding to unity */

/* Error values returned in Origin by COM_DAFG_CreateWaveform */
#define COM_DAFG_CRT_ERR_WAVE_NUM 0xFFFE /* no more waveforms available */
#define COM_DAFG_CRT_ERR_MEM_FULL 0xFFFF /* not enough memory space available */
int FAR _export pascal COM_DAFG_DeleteWaveform  (WORD   WaveformNumber);                                                                                       /* Delete waveform */
int FAR _export pascal COM_DAFG_CreateWaveform  (WORD & WaveformNumber, WORD & Origin, WORD   Size, double   Periods, const char Name [WAVEFORM_NAME_SIZE+1]); /* Create waveform */
int FAR _export pascal COM_DAFG_GetWaveform     (WORD   WaveformNumber, WORD & Origin, WORD & Size, double & Periods, char       Name [WAVEFORM_NAME_SIZE+1]); /* Get waveform */
int FAR _export pascal COM_DAFG_SetWaveformData (WORD   WaveformNumber, WORD DataBase, WORD   DataSize, const WORD Data [MAX_WAVEFORM_BLOCK_SIZE]);            /* Set waveform data */
int FAR _export pascal COM_DAFG_GetWaveformData (WORD   WaveformNumber, WORD DataBase, WORD & DataSize,       WORD Data [MAX_WAVEFORM_BLOCK_SIZE]);            /* Get waveform data */

/* General */
WORD FAR _export pascal COM_DAFG_Version(); /* Get the COM-DAFG software version */

int FAR _export pascal COM_DAFG_GetUptime (DWORD & Seconds, WORD & Milliseconds); /* Get device uptime */

int FAR _export pascal COM_DAFG_FW_Ver  (WORD & Version);            /* Get the COM-DAFG firmware version */
int FAR _export pascal COM_DAFG_FW_Date (char * FAR DateString);     /* Get the COM-DAFG firmware date, the buffer DateString should be 16 bytes long */
int FAR _export pascal COM_DAFG_Prod_ID (char * FAR Identification); /* Get the COM-DAFG product identification, the buffer Identification should be 81 bytes long */
int FAR _export pascal COM_DAFG_Prod_No (DWORD & Number);            /* Get the COM-DAFG product number */

int          FAR _export pascal COM_DAFG_State();                      /* Get software interface state */
const char * FAR _export pascal COM_DAFG_ErrorMessage();               /* Get the error message corresponding to the software interface state */
int          FAR _export pascal COM_DAFG_IO_State();                   /* Get serial port interface state */
const char * FAR _export pascal COM_DAFG_IO_ErrorMessage();            /* Get the error message corresponding to the serial port interface state */
const char * FAR _export pascal COM_DAFG_INI_ErrorMessage();           /* Get the error message corresponding to the ini file error */
void         FAR _export pascal COM_DAFG_GetIniParams (char * Buffer); /* Get the parameters read from the COM.ini file */


#ifdef __cplusplus
}
#endif


#endif//__COM_DAFG_H__
